#include "mainwidget.h"
#include "ui_mainwidget.h"
#include "qwordcompleter.h"

MainWidget::MainWidget(QWidget *parent) :
  QWidget(parent),
  ui(new Ui::MainWidget)
{
  ui->setupUi(this);
  //Список ключевых слов для автозаполнения
  QStringList keywords;
  keywords << "SELECT" << "FROM" << "WHERE" <<
              "ORDER" << "BY" << "DELETE" << "DROP";

  QWordCompleter* completer = new QWordCompleter(keywords, this);
  completer->setCaseSensitivity(Qt::CaseInsensitive);
  completer->setMinCompletionPrefixLength(2);
  completer->setWidget(ui->textEdit);  
  //связываем сигнал активации элемента списка со слотом замены текущего слова
  //на текст выбранного элемента
  connect(completer, SIGNAL(activated(QString)),
          completer, SLOT(replaceCurrentWord(QString)));

  //Использование QCompleter со стандартными виджетами
  QCompleter* stdCompleter = new QCompleter(keywords, this);
  //установление параметра чувствительности к регистру
  stdCompleter->setCaseSensitivity(Qt::CaseInsensitive);
  //выбор режима автозаполнения
  stdCompleter->setCompletionMode(QCompleter::PopupCompletion);
  //так делать не стоит (класс QCompleter корректно работает только с одним виджетом)
  ui->comboBox->setCompleter(stdCompleter);
  ui->lineEdit->setCompleter(stdCompleter);
  //вместо этого необходимо для каждого виджета создавать отдельный экземпляр QCompleter
}

MainWidget::~MainWidget()
{
  delete ui;
}
