#include "qwordcompleter.h"
#include <QEvent>
#include <QKeyEvent>
#include <QAbstractItemView>
#include <QTextEdit>
#include <QTextCursor>

QWordCompleter::QWordCompleter(const QStringList &completions, QObject *parent):
  QCompleter(completions, parent)
{
}

QWordCompleter::~QWordCompleter()
{
}


bool QWordCompleter::eventFilter(QObject *o, QEvent *e)
{
  //перехватываем только события нажатия на клавишу клавиатуры для виджета QTextEdit
  if (widget()->inherits("QTextEdit") && e->type() == QEvent::KeyPress){
    QKeyEvent* ke = static_cast<QKeyEvent*>(e);
    switch (ke->key()) {
    //перехват нажатия "Пробел" + "Ctrl"
    case Qt::Key_Space:
      if (ke->modifiers().testFlag(Qt::ControlModifier)){
        //приводим объект widget к классу QTextEdit
        QTextEdit* textEdit = qobject_cast<QTextEdit*>(widget());
        //получаем объект курсора
        QTextCursor textCursor = textEdit->textCursor();
        //выделяем отрезок текста от текущего положения до начала слова
        textCursor.movePosition(QTextCursor::StartOfWord, QTextCursor::KeepAnchor);
        //если выделенный отрезок слова не меньше параметра minCompletionPrefixLength
        if (textCursor.selectedText().length() >= minCompletionPrefixLength){
          //устанавливаем выделенный отрезок слова как фильтр модели автозаполнения
          setCompletionPrefix(textCursor.selectedText());
          QRect rect = QRect(textEdit->cursorRect().bottomLeft(), QSize(100, 5));
          //показываем список элементов автозаполнения
          complete(rect);
        }
        return true;
      }
      break;
    //перехват нажатия клавиш выбора элемента списка автозаполнения
    case Qt::Key_Enter:
    case Qt::Key_Return:
    case Qt::Key_Tab:
      //только если список автозаполнения уже отображен пользователю
      if (popup()->isVisible()){
        //прячем список
        popup()->hide();
        //если выбран валидный элемент модели, испускаем сигнал активации
        if (popup()->currentIndex().isValid()){
          emit activated(popup()->currentIndex());
          emit activated(popup()->currentIndex().data(completionRole()).toString());
        }
        return true;
      }
    default:
      break;
    }
  }
  //виджет не QTextEdit, автозаполнитель ведет себя как библиотечный
  return QCompleter::eventFilter(o, e);
}
int QWordCompleter::getMinCompletionPrefixLength() const
{
  return minCompletionPrefixLength;
}

void QWordCompleter::setMinCompletionPrefixLength(int value)
{
  minCompletionPrefixLength = value;
}

void QWordCompleter::replaceCurrentWord(QString text)
{
  QTextEdit* textEdit = qobject_cast<QTextEdit*>(widget());
  //получаем объект курсора
  QTextCursor textCursor = textEdit->textCursor();
  //устанавливаем курсор на начало слова
  textCursor.movePosition(QTextCursor::StartOfWord);
  //перемещаем курсор на конец слова, сохраняя положение левой границы выделения
  textCursor.movePosition(QTextCursor::EndOfWord, QTextCursor::KeepAnchor);
  //вставляем текст аргумента text вместо выделенного текста
  textCursor.insertText(text);
  //устанавливаем измененный объект курсора
  textEdit->setTextCursor(textCursor);
}

